==> tencentcloud-sdk-java-3.1.900-sources.jar: com/tencentcloudapi/dc/v20180410/models/DescribeDirectConnectTunnelsResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.dc.v20180410.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeDirectConnectTunnelsResponse extends AbstractModel {

    /**
    * 专用通道列表
    */
    @SerializedName("DirectConnectTunnelSet")
    @Expose
    private DirectConnectTunnel [] DirectConnectTunnelSet;

    /**
    * 符合专用通道数量。
    */
    @SerializedName("TotalCount")
    @Expose
    private Long TotalCount;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 专用通道列表 
     * @return DirectConnectTunnelSet 专用通道列表
     */
    public DirectConnectTunnel [] getDirectConnectTunnelSet() {
        return this.DirectConnectTunnelSet;
    }

    /**
     * Set 专用通道列表
     * @param DirectConnectTunnelSet 专用通道列表
     */
    public void setDirectConnectTunnelSet(DirectConnectTunnel [] DirectConnectTunnelSet) {
        this.DirectConnectTunnelSet = DirectConnectTunnelSet;
    }

    /**
     * Get 符合专用通道数量。 
     * @return TotalCount 符合专用通道数量。
     */
    public Long getTotalCount() {
        return this.TotalCount;
    }

    /**
     * Set 符合专用通道数量。
     * @param TotalCount 符合专用通道数量。
     */
    public void setTotalCount(Long TotalCount) {
        this.TotalCount = TotalCount;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public DescribeDirectConnectTunnelsResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeDirectConnectTunnelsResponse(DescribeDirectConnectTunnelsResponse source) {
        if (source.DirectConnectTunnelSet != null) {
            this.DirectConnectTunnelSet = new DirectConnectTunnel[source.DirectConnectTunnelSet.length];
            for (int i = 0; i < source.DirectConnectTunnelSet.length; i++) {
                this.DirectConnectTunnelSet[i] = new DirectConnectTunnel(source.DirectConnectTunnelSet[i]);
            }
        }
        if (source.TotalCount != null) {
            this.TotalCount = new Long(source.TotalCount);
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "DirectConnectTunnelSet.", this.DirectConnectTunnelSet);
        this.setParamSimple(map, prefix + "TotalCount", this.TotalCount);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}

==> tencentcloud-sdk-java-3.1.1000-sources.jar: com/tencentcloudapi/dc/v20180410/models/DescribeDirectConnectTunnelsResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.dc.v20180410.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeDirectConnectTunnelsResponse extends AbstractModel {

    /**
    * 专用通道列表
    */
    @SerializedName("DirectConnectTunnelSet")
    @Expose
    private DirectConnectTunnel [] DirectConnectTunnelSet;

    /**
    * 符合专用通道数量。
    */
    @SerializedName("TotalCount")
    @Expose
    private Long TotalCount;

    /**
    * 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 专用通道列表 
     * @return DirectConnectTunnelSet 专用通道列表
     */
    public DirectConnectTunnel [] getDirectConnectTunnelSet() {
        return this.DirectConnectTunnelSet;
    }

    /**
     * Set 专用通道列表
     * @param DirectConnectTunnelSet 专用通道列表
     */
    public void setDirectConnectTunnelSet(DirectConnectTunnel [] DirectConnectTunnelSet) {
        this.DirectConnectTunnelSet = DirectConnectTunnelSet;
    }

    /**
     * Get 符合专用通道数量。 
     * @return TotalCount 符合专用通道数量。
     */
    public Long getTotalCount() {
        return this.TotalCount;
    }

    /**
     * Set 符合专用通道数量。
     * @param TotalCount 符合专用通道数量。
     */
    public void setTotalCount(Long TotalCount) {
        this.TotalCount = TotalCount;
    }

    /**
     * Get 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public DescribeDirectConnectTunnelsResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeDirectConnectTunnelsResponse(DescribeDirectConnectTunnelsResponse source) {
        if (source.DirectConnectTunnelSet != null) {
            this.DirectConnectTunnelSet = new DirectConnectTunnel[source.DirectConnectTunnelSet.length];
            for (int i = 0; i < source.DirectConnectTunnelSet.length; i++) {
                this.DirectConnectTunnelSet[i] = new DirectConnectTunnel(source.DirectConnectTunnelSet[i]);
            }
        }
        if (source.TotalCount != null) {
            this.TotalCount = new Long(source.TotalCount);
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "DirectConnectTunnelSet.", this.DirectConnectTunnelSet);
        this.setParamSimple(map, prefix + "TotalCount", this.TotalCount);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}
